@@ -16,14 +16,12 @@ from viewmask.utils import (
 from os.path import splitext
 
 
-# TODO: eventually napari will rename is_pyramid to multiscale:
-# https://github.com/napari/napari/commit/1adff3e467768076643e8e02a12d4bf726f563a9
-
 INTERACTIVE_OPTION_HELP = 'If passed, the annotations will be rendered as ' + \
     'napari objects rather than rendered together and displayed as an image.'
 
 
 @click.group()
+@click.version_option()
 def cli():
     pass
 
@@ -43,19 +41,20 @@ def cli():
     help=INTERACTIVE_OPTION_HELP
 )
 def view_annotations(annotations, interactive):
-    if splitext(annotations)[1] == '.npy' and interactive is True:
+    annotations_are_npy = splitext(annotations)[1] == '.npy'
+    if annotations_are_npy and interactive is True:
         raise ValueError(
             "The interactive flag cannot be passed with a numpy mask.")
 
-    # TODO: get rid of this, some XMLs might actually be unparseable:
     try:
         tree = ET.parse(annotations)
     except ET.ParseError:
+        # TODO: don't just do nothing, some XMLs might actually be unparseable:
         pass
     with napari.gui_qt():
         viewer = napari.Viewer()
         if interactive:
-            regions = xml_to_contours(tree, 'napari')
+            regions = xml_to_contours(tree, transpose=True)
             line_color = get_stroke_color(tree)
             viewer.add_shapes(
                 regions,
@@ -67,13 +66,13 @@ def view_annotations(annotations, interactive):
                 name='centers'
             )
         else:
-            if splitext(annotations)[1] == '.npy':
+            if annotations_are_npy:
                 rendered_annotations = np.load(annotations)
                 viewer.add_image(
                     rendered_annotations,
                     name='annotations',
                     blending='additive',
-                    is_pyramid=False,
+                    multiscale=False,
                 )
             else:
                 rendered_annotations = xml_to_image(tree)
@@ -81,7 +80,7 @@ def view_annotations(annotations, interactive):
                     rendered_annotations,
                     name='annotations',
                     blending='additive',
-                    is_pyramid=False,
+                    multiscale=False,
                 )
             centers = centers_of_contours(
                 mask_to_contours(rendered_annotations))
@@ -90,7 +89,7 @@ def view_annotations(annotations, interactive):
                 name='centers',
                 rgb=True,
                 blending='additive',
-                is_pyramid=False,
+                multiscale=False,
             )
 
 
@@ -99,7 +98,7 @@ def view_annotations(annotations, interactive):
 def view_image(image):
     da_img = file_to_dask_array(image)
     with napari.gui_qt():
-        _ = napari.view_image(da_img, name='image', is_pyramid=False)
+        _ = napari.view_image(da_img, name='image', multiscale=False)
 
 
 @cli.command(name='overlay')
@@ -115,9 +114,8 @@ def view_image(image):
     help=INTERACTIVE_OPTION_HELP
 )
 def view_overlay(image, annotations, interactive):
-    # TODO: use assert?
-    # TODO: use annotations.endswith('.npy')?
-    if splitext(annotations)[1] == '.npy' and interactive is True:
+    annotations_are_npy = splitext(annotations)[1] == '.npy'
+    if annotations_are_npy and interactive is True:
         raise ValueError(
             "The interactive flag cannot be passed with a numpy mask.")
 
@@ -130,12 +128,12 @@ def view_overlay(image, annotations, interactive):
             da_img,
             name='image',
             blending='additive',
-            is_pyramid=False,
+            multiscale=False,
         )
 
         if interactive:
             tree = ET.parse(annotations)
-            regions = xml_to_contours(tree, 'napari')
+            regions = xml_to_contours(tree, transpose=True)
             line_color = get_stroke_color(tree)
             viewer.add_shapes(
                 regions,
@@ -147,13 +145,13 @@ def view_overlay(image, annotations, interactive):
                 name='centers'
             )
         else:
-            if splitext(annotations)[1] == '.npy':
+            if annotations_are_npy:
                 rendered_annotations = np.load(annotations)
                 viewer.add_image(
                     rendered_annotations,
                     name='annotations',
                     blending='additive',
-                    is_pyramid=False,
+                    multiscale=False,
                 )
             else:
                 tree = ET.parse(annotations)
@@ -162,7 +160,7 @@ def view_overlay(image, annotations, interactive):
                     rendered_annotations,
                     name='annotations',
                     blending='additive',
-                    is_pyramid=False,
+                    multiscale=False,
                 )
             centers = centers_of_contours(
                 mask_to_contours(rendered_annotations))
@@ -171,7 +169,7 @@ def view_overlay(image, annotations, interactive):
                 name='centers',
                 rgb=True,
                 blending='additive',
-                is_pyramid=False,
+                multiscale=False,
             )
 
 
